#
# spec file for package python-python-subunit
#
# Copyright (c) 2015 SUSE LINUX GmbH, Nuernberg, Germany.
#
# All modifications and additions to the file contributed by third parties
# remain the property of their copyright owners, unless otherwise agreed
# upon. The license for this file, and modifications and additions to the
# file, is the same license as for the pristine package itself (unless the
# license for the pristine package is not an Open Source License, in which
# case the license is the MIT License). An "Open Source License" is a
# license that conforms to the Open Source Definition (Version 1.9)
# published by the Open Source Initiative.

# Please submit bugfixes or comments via http://bugs.opensuse.org/
#


Name:           python-python-subunit
Version:        1.0.0
Release:        4.2
Summary:        Python implementation of subunit test streaming protocol
License:        Apache-2.0 or BSD-3-Clause
Group:          Development/Languages/Python
Url:            http://launchpad.net/subunit
Source:         http://pypi.python.org/packages/source/p/python-subunit/python-subunit-%{version}.tar.gz
# PATCH-FIX-OPENSUSE speilicke@suse.com -- Filters are installed in /usr/bin.
Patch0:         python-subunit-filter-path.patch
BuildRequires:  python-devel
# Test requriements
BuildRequires:  python-testscenarios
BuildRequires:  python-testtools >= 0.9.34
Requires:       python-extras
Requires:       python-testtools >= 0.9.34
Requires(post): update-alternatives
Requires(postun): update-alternatives
BuildRoot:      %{_tmppath}/%{name}-%{version}-build
%if 0%{?suse_version} && 0%{?suse_version} <= 1110
%{!?python_sitelib: %global python_sitelib %(python -c "from distutils.sysconfig import get_python_lib; print get_python_lib()")}
%else
BuildArch:      noarch
%endif

%description
Subunit is a streaming protocol for test results. The protocol is human
readable and easily generated and parsed. By design all the components of 
the protocol conceptually fit into the xUnit TestCase->TestResult interaction.

Subunit comes with command line filters to process a subunit stream and
language bindings for python, C, C++ and shell. Bindings are easy to write
for other languages.

%prep
%setup -q -n python-subunit-%{version}
%patch0 -p1
for B in subunit2csv subunit-2to1 subunit-1to2 subunit-filter subunit-ls subunit-notify subunit-stats subunit-tags subunit-output subunit2gtk subunit2junitxml subunit2pyunit tap2subunit ; do
    sed -i "s|'filters/$B'|'filters/$B-%{py_ver}'|" setup.py
    mv filters/$B filters/$B-%{py_ver}
done
sed -i "s|'subunit-filter'|'subunit-filter-%{py_ver}'|" python/subunit/tests/test_subunit_filter.py

%build
python setup.py build

%install
python setup.py install --prefix=%{_prefix} --root=%{buildroot}
#NOTE(saschpe): The testsuite demands executables:
chmod +x %{buildroot}%{python_sitelib}/subunit/tests/sample-*.py
mkdir -p %{buildroot}%{_sysconfdir}/alternatives
for B in subunit2csv subunit-2to1 subunit-1to2 subunit-filter subunit-ls subunit-notify subunit-stats subunit-tags subunit-output subunit2gtk subunit2junitxml subunit2pyunit tap2subunit ; do
    touch %{buildroot}%{_sysconfdir}/alternatives/$B
    ln -sf %{_sysconfdir}/alternatives/$B %{buildroot}/%{_bindir}/$B
done

%check
#NOTE(saschpe): Pesky testsuite doesn't know about buildroot
sed -i "s|'/',|'%{buildroot}',|" %{buildroot}%{python_sitelib}/subunit/tests/test_subunit_filter.py
PYTHONPATH=%{buildroot}%{python_sitelib} python -m testtools.run subunit.test_suite
sed -i "s|'%{buildroot}',|'/',|" %{buildroot}%{python_sitelib}/subunit/tests/test_subunit_filter.py
# Fixup compiled python module afterwards:
%if 0%{?suse_version}
%py_compile %{buildroot}%{python_sitelib}/subunit/tests
%endif

%post
update-alternatives \
    --install %{_bindir}/subunit-2to1 subunit-2to1 %{_bindir}/subunit-2to1-%{py_ver} 20 \
    --slave %{_bindir}/subunit-1to2 subunit-1to2 %{_bindir}/subunit-1to2-%{py_ver} \
    --slave %{_bindir}/subunit2csv subunit2csv %{_bindir}/subunit2csv-%{py_ver} \
    --slave %{_bindir}/subunit-filter subunit-filter %{_bindir}/subunit-filter-%{py_ver} \
    --slave %{_bindir}/subunit-ls subunit-ls %{_bindir}/subunit-ls-%{py_ver} \
    --slave %{_bindir}/subunit-notify subunit-notify %{_bindir}/subunit-notify-%{py_ver} \
    --slave %{_bindir}/subunit-stats subunit-stats %{_bindir}/subunit-stats-%{py_ver} \
    --slave %{_bindir}/subunit-tags subunit-tags %{_bindir}/subunit-tags-%{py_ver} \
    --slave %{_bindir}/subunit-output subunit-output %{_bindir}/subunit-output-%{py_ver} \
    --slave %{_bindir}/subunit2gtk subunit2gtk %{_bindir}/subunit2gtk-%{py_ver} \
    --slave %{_bindir}/subunit2junitxml subunit2junitxml %{_bindir}/subunit2junitxml-%{py_ver} \
    --slave %{_bindir}/subunit2pyunit subunit2pyunit %{_bindir}/subunit2pyunit-%{py_ver} \
    --slave %{_bindir}/tap2subunit tap2subunit %{_bindir}/tap2subunit-%{py_ver}

%postun
if [ $1 -eq 0 ] ; then
    update-alternatives --remove subunit %{_bindir}/subunit-%{py_ver}
fi

%files
%defattr(-,root,root,-)
%doc README NEWS
%{_bindir}/subunit2csv
%{_bindir}/subunit2csv-%{py_ver}
%{_bindir}/subunit-2to1
%{_bindir}/subunit-2to1-%{py_ver}
%{_bindir}/subunit-1to2
%{_bindir}/subunit-1to2-%{py_ver}
%{_bindir}/subunit-filter
%{_bindir}/subunit-filter-%{py_ver}
%{_bindir}/subunit-ls
%{_bindir}/subunit-ls-%{py_ver}
%{_bindir}/subunit-notify
%{_bindir}/subunit-notify-%{py_ver}
%{_bindir}/subunit-stats
%{_bindir}/subunit-stats-%{py_ver}
%{_bindir}/subunit-tags
%{_bindir}/subunit-tags-%{py_ver}
%{_bindir}/subunit-output
%{_bindir}/subunit-output-%{py_ver}
%{_bindir}/subunit2gtk
%{_bindir}/subunit2gtk-%{py_ver}
%{_bindir}/subunit2junitxml
%{_bindir}/subunit2junitxml-%{py_ver}
%{_bindir}/subunit2pyunit
%{_bindir}/subunit2pyunit-%{py_ver}
%{_bindir}/tap2subunit
%{_bindir}/tap2subunit-%{py_ver}
%ghost %{_sysconfdir}/alternatives/subunit2csv
%ghost %{_sysconfdir}/alternatives/subunit-2to1
%ghost %{_sysconfdir}/alternatives/subunit-1to2
%ghost %{_sysconfdir}/alternatives/subunit-filter
%ghost %{_sysconfdir}/alternatives/subunit-ls
%ghost %{_sysconfdir}/alternatives/subunit-notify
%ghost %{_sysconfdir}/alternatives/subunit-stats
%ghost %{_sysconfdir}/alternatives/subunit-tags
%ghost %{_sysconfdir}/alternatives/subunit-output
%ghost %{_sysconfdir}/alternatives/subunit2gtk
%ghost %{_sysconfdir}/alternatives/subunit2junitxml
%ghost %{_sysconfdir}/alternatives/subunit2pyunit
%ghost %{_sysconfdir}/alternatives/tap2subunit
%{python_sitelib}/subunit
%{python_sitelib}/python_subunit-%{version}-py%{py_ver}.egg-info

%changelog
* Mon Jul 27 2015 seife+obs@b1-systems.com
- fix RHEL7 build by disabling %%py_compile (done by rpmbuild anyway)
* Mon Dec 29 2014 p.drouand@gmail.com
- Update to version 1.0.0
  + Tests have been fixed with testtools 1.2.0 and above.
  + With testtools 1.4.0 and above import errors are now
  shown in detail by ``subunit.run``.
- Fix build on Factory
* Sat Sep 27 2014 dmueller@suse.com
- update to 0.0.21:
  * Brown bag bugfix - 0.0.20's setup.py referenced cvs not csv.
    (Robert Collins, #1361924)
  * subunit2csv is now installed when using pip.
    (Robert Collins, #1279669)
  * testscenarios is now a test dependency, not an install dependency.
    (Arfrever Frehtes Taifersar Arahesis, #1292757)
  * The python-subunit tarball can now have setup run from the current
    directory. (Robert Collins, #1361857)
  * ``subunit.run`` in Python will now exit 0 as long as the test stream has
    been generated correctly - this has always been the intent but API friction
    with testtools had prevented it working.
    (Robert Collins)
- Remove python-testscenarios dependency; not needed anymore
* Thu Feb 13 2014 speilicke@suse.com
- Implement update-alternatives
* Thu Jan 30 2014 speilicke@suse.com
- Update to version 0.0.18:
  + Fix compatibility with testtools 0.9.35 which dropped the 'all' compat
    symbol. This breaks support for Python versions lower than 2.6.
- Changes from version 0.0.17:
  + Add subunit-output tool that can generate a Subunit v2 bytestream from
    arguments passed on the command line. (Thomi Richards, #1252084)
- Add /usr/bin/subunit-output
- Add python-subunit-filter-path.patch:
  + Fix filters path in testsuite
- Properly run testsuite
- Fix requirements
* Mon Jan 13 2014 dmueller@suse.com
- update to 0.0.16:
  * Perl files should now honour perl system config.
  * Python 3.1 and 3.2 have an inconsistent memoryview implementation which
  required a workaround for NUL byte detection. (Robert Collins, #1216246)
  * The test suite was failing 6 tests due to testtools changing it's output
  formatting of exceptions. (Robert Collins)
  * V2 parser errors now set appropriate mime types for the encapsulated packet
  data and the error message. (Robert Collins)
  * When tests fail to import python subunit.run -l ... will now write a
  subunit file attachment listing the failed imports and exit 2
- Fix package requires
* Tue Sep  3 2013 dmueller@suse.com
- update to 0.0.15:
  * Clients of subunit did not expect memoryview objects in StreamResult events.
  * Memoryview and struct were mutually incompatible in 2.7.3 and 3.2.
  * Memoryview detection was broken and thus it's use was never really tested.
  * TestProtocol2's tag tests were set sort order dependent.
  * TestTestProtocols' test_tags_both was set sort order dependent.
  * TestTestProtocols' test_*_details were dictionary sort order dependent.
  * TestSubUnitTags's test_add_tag was also se sort order dependent.
* Fri Jul 19 2013 dmueller@suse.com
- update to 0.0.13:
  * Fix GPL licensing issue
  * subunit-stats no longer outputs encapsulated stdout as subunit.
  * The logic for subunit.run is now importable via python -
    subunit.run.main. (Robert Collins, #606770)
* Sun Jun  2 2013 dmueller@suse.com
- update to 0.0.12:
  * fix data corruption bug in v2 protocol streaming
* Mon Apr 29 2013 dmueller@suse.com
- update to 0.0.11:
  * v2 protocol draft included in this release. The v2 protocol trades off human
  readability for a massive improvement in robustness, the ability to represent
  concurrent tests in a single stream, cheaper parsing, and that provides
  significantly better in-line debugging support and structured forwarding
  of non-test data (such as stdout or stdin data).
  * make_stream_binary is now public for reuse. (Robert Collins)
  * Streams with no fileno() attribute are now supported, but they are not
  checked for being in binary mode: be sure to take care of that if using
  the library yourself. (Robert Collins)
* Thu Jan 17 2013 cfarrell@suse.com
- license update: Apache-2.0 or BSD-3-Clause
  Look at the README file
* Tue Jan 15 2013 saschpe@suse.de
- Run testsuite
- Package README and NEWS
* Tue Jan 15 2013 dmueller@suse.com
- Initial packaging (0.0.9)
